Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(35)

Unified Diff: client/tests/client/dom/WebGL1Test.dart

Issue 10222026: Migrate dom tests to dart:html. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: client/tests/client/dom/WebGL1Test.dart
diff --git a/client/tests/client/dom/WebGL1Test.dart b/client/tests/client/dom/WebGL1Test.dart
index 70efa2130a22a050ebfa7969804aba5c9fc38edc..6873ea9bb0585e202c33bd5a916a074fc96d2309 100644
--- a/client/tests/client/dom/WebGL1Test.dart
+++ b/client/tests/client/dom/WebGL1Test.dart
@@ -1,12 +1,12 @@
#library('WebGL1Test');
#import('../../../../lib/unittest/unittest.dart');
#import('../../../../lib/unittest/dom_config.dart');
#import('dart:dom');
// Test that WebGL is present in dart:dom API
main() {
- useDomConfiguration();
+ useHtmlConfiguration();
test('simple', () {
var canvas = document.createElement("canvas");
@@ -1,12 +1,12 @@
#library('WebGL1Test');
#import('../../../../lib/unittest/unittest.dart');
-#import('../../../../lib/unittest/dom_config.dart');
-#import('dart:dom');
+#import('../../../../lib/unittest/html_config.dart');
+#import('dart:html');
-// Test that WebGL is present in dart:dom API
+// Test that WebGL is present in dart:html API
main() {

Powered by Google App Engine
This is Rietveld 408576698